drop table events;
drop table eventinfo;
drop table eventplace;
drop table eventtimes;
drop view  eventview;

create table events (
  eventid number,
  title char(80),
  category char(20),
  costlevel number,
  costdesc char(80),
  loccode char(10),
  moreinfo char(80)
);

create table eventtimes (
  eventid number,
  edate   date,
  time    char(8),
  length  number
);  

create table eventinfo (
  eventid number,
  about1  char(80),
  about2  char(80),
  about3  char(80),
  about4  char(80),
  about5  char(80),
  about6  char(80),
  about7  char(80),
  about8  char(80)
);

create table eventplace (
  loccode char(18),
  building char(80),
  room char(80),
  address char(80),
  city char(80)
);


create view eventview (eventid, title, category, costlevel, costdesc, building,
		       room, address, city, moreinfo, edate, time, length)
		       as
		select distinct events.eventid, title, category, costlevel, costdesc, 
		       building,
		       room, address, city, moreinfo, edate, time, length
		       from events, eventtimes, eventinfo, eventplace
                       where
                        events.eventid = eventtimes.eventid and
                        events.loccode = eventplace.loccode;


insert into events values (1,'The Hang Ups with Saucer and Alligator Gun',
'CONCERT', 5,'$4 Students, $5 Others', 'CMU-WHOLE',
'Call 624-5105');

insert into eventtimes values(1, '22-Oct-93', '8:30pm', 240);


insert into events values(2,'PERSI DIACONIS -- ON COINCIDENCES',
'LECTURE', 0, 'Free', 'NRUP-AUD', 
'call (612) 625-5591 or contact dept@math.umn.edu');

insert into eventtimes values(2, '9-Nov-93', '4:00pm', 60);


insert into events values(3,'Silha Lecture - L.D. Boccardi',
'LECTURE', 0,'Free', 'HHH-COWLES',
'call 625-3421');

insert into eventtimes values(3, '19-Oct-93', '12:15pm', 60);


insert into events values(4,'New Art Museums Conference',
'CONFERENCE', 0, 'Free, reservations required', 'CMU-GH',
'call 624-6053 for information and reservations'); 

insert into eventtimes values(4, '10-Dec-93', '9:00am', 480);
insert into eventtimes values(4, '11-Dec-93', '9:00am', 480);


insert into events values(5,'American Indian Dance Theatre',
'DANCE', 15, 'Tickets: $19.50, $14.50, $9.50',
'NRUP-AUD', 'Northrup Ticket Office 624-2345');

insert into eventtimes values(5, '6-Nov-93', '8:00pm', 120);


insert into events values(6,'Amanda Miller Dance Company',
'DANCE', 15, 'Tickets: $19.50, $14.50, $9.50',
'NRUP-AUD', 'Northrup Ticket Office 624-2345');

insert into eventtimes values(6, '20-Nov-93', '8:00pm', 120);


insert into events values(7,'Dance Theatre of Harlem',
'DANCE', 20, 'Tickets: $19.50, $14.50, $9.50',
'NRUP-AUD', 'Northrup Ticket Office 624-2345');

insert into eventtimes values(7, '11-Feb-94', '8:00pm', 120);
insert into eventtimes values(7, '12-Feb-94', '8:00pm', 120);


insert into events values(9,'Principal Dancers of New York City Ballet',
'DANCE', 26, 'Tickets: $33.50, $25.50, $19.50',
'NRUP-AUD', 'Northrup Ticket Office 624-2345');

insert into eventtimes values(9, '8-Mar-94', '8:00pm', 120);
insert into eventtimes values(9, '9-Mar-94', '8:00pm', 120);

insert into events values(10, 'Bebe Miller Dance Company',
'DANCE', 15, 'Tickets: $19.50, $14.50, $9.50',
'NRUP-AUD', 'Northrup Ticket Office 624-2345');

insert into eventtimes values(10, '19-Mar-94', '8:00pm', 120);


insert into events values(11, 'Paul Taylor Dance Company',
'DANCE', 15, 'Tickets: $19.50, $14.50, $9.50',
'NRUP-AUD', 'Northrup Ticket Office 624-2345');

insert into eventtimes values(11, '24-Mar-94', '8:00pm', 120);



insert into events values(12, 'Julius Hemphill',
'DANCE', 15, 'Tickets: $15.00, $13.00, $11.00',
'MANN-AUD', 'Northrup Ticket Office 624-2345');

insert into eventtimes values(12, '6-Apr-94', '8:00pm', 120);


insert into events values(13, 'Microsoft Presentation',
'LECTURE', 0, 'Free',
'CMU-THE', 'call 626-9816');

insert into eventtimes values(13, '22-Oct-93', '8:00pm', 120);


insert into events values(14, 'Drunk Driving Awareness Day: Root Beer Keg',
'EVENT', 0, 'Free',
'CMU-CL', '');

insert into eventtimes values(14, '10-Nov-93', '11:00am', 120);
insert into eventtimes values(14, '10-Nov-93', '4:00pm', 120);


insert into events values(15, 'Myers-Brigg Type Indicator Test',
'SPECIAL EVENT', 4, 'Fee of $3.50', 'EDDY109', '');

insert into eventtimes values(15, '3-Nov-93', '2:30pm', 60);
insert into eventtimes values(15, '10-Nov-93', '2:30pm', 60);


insert into events values(16, 'Ski Swap Sale',
'FAIR', 0, 'Free', 'SPSC-NSB', '');
insert into eventtimes values(16, '10-Nov-93', '9:00am',660);

insert into events values(17, 'Cracker/Rex Daisy/Counting Crows',
'CONCERT', 7, '$6 Advance, $8 Door', 'FIRST-AVE', 'call 338-8388');
insert into eventtimes values(17, '3-Nov-93', '6:00pm', 180);

insert into events values(18, 'The Remains of the Day - Special Screening',
'FILM', 6, '$5 Walker members, $6 nonmembers', 'WALKER-AUD', 'call 375-7622');
insert into eventtimes values(18,'3-Nov-93','8:00pm', 90);

insert into events values(19, 'Didjits/Pegboy',
'CONCERT', 3, '$3 Cover', 'UPTBAR', 'call 823-4719');
insert into eventtimes values(19,'7-Nov-93','9:00pm', 240);

insert into events values(20, 'Robert Plant/Cry of Love',
'CONCERT', 27, 'Tickets: $22.50-$32.50', 'NRUP-AUD',
'call 989-5151 (Ticketmaster)');
insert into eventtimes values(20, '8-Nov-93', '7:30pm', 240);

insert into events values(21, 'Minnesota Timberwolves vs. Utah Jazz',
'SPORTS', 15, 'ticket prices vary', 'TARGET-CTR', 
'call 989-5151 (Ticketmaster)');
insert into eventtimes values(21, '6-Nov-93', '7:00pm', 120);

insert into events values(22, 'Minnesota Vikings vs. San Diego',
'SPORTS', 20, 'ticket prices vary', 'METRODOME',
'call 825-DOME or 989-5151');
insert into eventtimes values(22, '7-Nov-93', '12:00pm', 120);

insert into events values(23, 'Squeeze with Over the Rhine',
'CONCERT', 5, 'tickets $5', 'FIRST-AVE', 'call 338-8388');
insert into eventtimes values(23, '7-Nov-93', '8:00pm', 300);

insert into events values(24, 'Joe Paddock Reading',
'READING', 0, 'Free', 'BORDERS-UPTN', 'call 825-0336');
insert into eventtimes values(24, '3-Nov-93', '7:30pm', 60);

insert into events values(25, 'Sarah Shulman, "Empathy" Reading',
'READING', 0, 'Free', 'WLKR-GALL8', 'call 375-7622');
insert into eventtimes values(25, '3-Nov-93', '8:00pm', 60);



insert into eventplace values('WLKR-GALL8', 'Walker Art Center',
'Gallery 8 Restaurant', 'Hennepin Ave.', 'Minneapolis');

insert into eventplace values('BORDERS-UPTN', 
'Borders Book Shop, Calhoun Square', '', '3001 S. Hennepin Ave.',
'Minneapolis');

insert into eventplace values('METRODOME', 'Hubert H. Humphrey Metrodome',
'', '501 S. Chicago Ave', 'Minneapolis');

insert into eventplace values('TARGET-CTR', 'Target Center', 'Main Arena',
'600 N. First Ave.', 'Minneapolis');

insert into eventplace values('UPTBAR', 'Uptown Bar', '',
'3018 Hennepin Ave S', 'Minneapolis');

insert into eventplace values('WALKER-TH', 'Walker Art Center','Auditorium',
'', 'Minneapolis');

insert into eventplace values('FIRST-AVE', 'First Avenue', 'Main Room',
'701 First Ave. N.', 'Minneapolis');

insert into eventplace values('SPSC-NSB', 'St. Paul Student Center',
'North Star Ballroom', '', 'St. Paul');

insert into eventplace values('EDDY109', 'Eddy Hall', '109','',
'Minneapolis');

insert into eventplace values('CMU-WHOLE', 'Coffman Memorial Union', 
'The Whole -- B1', '1500 Washington Ave SE', 'Minneapolis');

insert into eventplace values('NRUP-AUD', 'Northrup Auditorium',
'Main Auditorium', 'xxx', 'Minneapolis');

insert into eventplace values('HHH-COWLES', 'Hubert H. Humphrey Center',
'Cowles Auditorium', '', 'Minneapolis');

insert into eventplace values('CMU-GH', 'Coffman Memorial Union',
'Great Hall', '1500 Washington Ave SE', 'Minneapolis');

insert into eventplace values('MANN-AUD', 'Ted Mann Concert Hall',
'Main Auditorium', 'xx', 'Minneapolis');

insert into eventplace values('CMU-THE', 'Coffman Memorial Union',
'Theater', '1500 Washington Ave SE', 'Minneapolis');

insert into eventplace values('CMU-CL', 'Coffman Memorial Union',
'Commuter Lounge', '1500 Washington Ave SE', 'Minneapolis');


insert into eventinfo values (
2,
'Coincidences can astound us.  Sometimes carefull thinking can make them',
'seem less mysterious.  Professor Diaconis will explore examples from',
'C.G. Jungs work on synchronicity to recent studies of parapsychology.',
'','','','','');

insert into eventinfo values (
3,
'Nuisance or News: A Report Card on the Press',
'',
'Louis D. Boccardi, President and CEO, Associated Press',
'The Annual Silha Lecture, of the Silha Center for the',
'Study of Media Ethics and Law',
'','','');

insert into eventinfo values (
4,
'Frank Gehry, Peter Eisenman, Steven Izenour, Richard Meier, others',
'',
'This two-day symposium will examine the recent innovative approaches',
'to museum architecture by many leading architects, who will be present',
'to discuss their work.  Public discussions will include architectural',
'creativity, critical perceptions, the presentation of art and',
'artifacts, and the role of curators, directors, boards and the public',
'');

insert into eventinfo values (
13,
'Mr. Jim Reitz, Senior Systems Architect in the Central U.S. for Microsoft,',
'will do a presentation followed by a "question and answer" session.',
'',
'As background, Mr. Reitz is responsible for helping customers understand',
'Microsofts advanced technology and strategic directions. Jim speaks frequently',
'at both public events and customer briefings on operating systems, development',
'tools, connectivity, and corporate applications downsizing.',
'');

insert into eventinfo values (18,
'The first person account of a very traditional English butler played by',
'Anthony Hopkins.  A Merchant-Ivory production with Emma Thompson as the',
'housekeeper.',
'local premiere',
'','','',''
);

insert into eventinfo values(24,
'Joe Paddock, Minnesota writer, reads from his latest collection of poetry',
'"Boars Dance"."',
'','','','','',''
);

insert into eventinfo values(25,
'Sarah Shulman reads from her new novel "Empathy."  In her latest work,',
'Shulman, a regular contributor to the Village Voice, Nation and Mother',
'Jones, explores such issues as homophobia, AIDS, homelessness and drugs',
'','','','','');